(function( $ ) {
	'use strict';

	/**
	 * Vars
	 */
	window.ayg_is_ready = false;
	
	/**
	 * Init Automatic YouTube Gallery. Called when YouTube API is ready.
	 *
	 * @since 2.0.0
	 */
	function ayg_init() {
		if ( true == window.ayg_is_ready ) {
			return false;
		}

		window.ayg_is_ready = true;
		$( document ).trigger( 'ayg.ready' );
		
		// Classic Theme
		$( '.ayg-theme-classic' ).each(function() {
			init_classic_theme( $( this ) );
		});	
		
		// Single Video
		$( '.ayg-theme-single' ).each(function() {
			init_single_video( $( this ) );
		});

		// Livestream
		$( '.ayg-theme-livestream' ).each(function() {
			init_livestream( $( this ) );
		});
	}

	/**
	 * Init Classic Theme.
	 *
	 * @since 2.0.0
	 */
	function init_classic_theme( $container ) {
		++ayg_public.gallery_index;

		$container.addClass( 'ayg-theme-initialized' );		

		var params = $container.data( 'params' );

		var $current_item = $container.find( '.ayg-item' ).eq(0);

		var video_id = $current_item.find( '.ayg-thumbnail' ).data( 'id' );			
		
		var player_id = 'ayg-player-' + ayg_public.gallery_index;
		$container.find( '.ayg-player-iframe' ).attr( 'id', player_id );

		var $pagination = $container.find( '.ayg-pagination' );
		var $next_button = null;
		var pagination_type = 'none';
		if ( $pagination.length > 0 ) {
			$next_button = $pagination.find( '.ayg-pagination-next-btn' );
			pagination_type = $next_button.data( 'type' );
		}

		// Player
		var player = ayg_init_player( player_id, {			
			custom: {
				params: params,
				image: $current_item.find( '.ayg-thumbnail-image' ).attr( 'src' )
			},
			events: {
				'onStateChange': function( e ) {
					// On Playing
					if ( e.data == YT.PlayerState.PLAYING ) {
						ayg_pause_other_players( player_id );
					}

					// On Ended
					if ( e.data == YT.PlayerState.ENDED ) {
						if ( 1 == params.autoadvance ) {
							player.stop();

							if ( $current_item.is( ':visible' ) ) {
								if ( $current_item.is( ':last-child' ) ) {
									if ( 'more' == pagination_type || 'none' == pagination_type ) {
										if ( 1 == params.loop ) {
											$container.find( '.ayg-item' ).eq(0).trigger( 'click' );
										}
									} else {
										// Load Next Page
										if ( $next_button.is( ':visible' ) ) {					
											$next_button.trigger( 'click' );

											var __interval = setInterval(
												function() {												
													if ( 0 == $container.find( '.ayg-pagination.ayg-loading' ).length ) {
														clearInterval( __interval );
														$container.find( '.ayg-item' ).eq(0).trigger( 'click' );
													}												
												}, 
												1000
											);									
										}									
									}
								} else {
									$current_item.next( '.ayg-item' ).trigger( 'click' );
								}
							} else {
								$container.find( '.ayg-item' ).eq(0).trigger( 'click' );
							}
						} else {
							if ( 1 == params.loop ) {
								player.play();
							} else {
								player.stop();
							}
						}
					}				 
				}
			}
		});

		// Grid: On thumbnail clicked
		$container.on( 'click', '.ayg-item', function() {
			$current_item = $( this );

			$container.find( '.ayg-active' ).removeClass( 'ayg-active' );			
			$current_item.addClass( 'ayg-active' );

			// Change video
			video_id = $current_item.find( '.ayg-thumbnail' ).data( 'id' );

			player.change({
				id: video_id,
				image: $current_item.find( '.ayg-thumbnail-image' ).attr( 'src' )
			});
			
			if ( 1 == params.player_title ) {
				var title = $current_item.find( '.ayg-thumbnail' ).data( 'title' );				
				$container.find( '.ayg-player-title' ).html( title );
			}

			if ( 1 == params.player_description ) {
				var description = $current_item.find( '.ayg-thumbnail-description' ).html();
				$container.find( '.ayg-player-description' ).html( description );
			}
			
			// Scroll to Top
			$( 'html, body' ).animate({
				scrollTop: $container.offset().top - ayg_public.top_offset
			}, 500, function() {
				// Change URL in Browser Address Bar
				var url = $current_item.find( '.ayg-thumbnail' ).data( 'url' );
				if ( '' != url ) {
					window.history.replaceState( null, null, url );
				}				
			});	
			
			// Load Next Page
			if ( 1 == params.autoadvance && 'more' == pagination_type ) {
				if ( $current_item.is( ':last-child' ) && $next_button.is( ':visible' ) ) {					
					$next_button.trigger( 'click' );
				}
			}
		});

		// Pagination
		if ( $pagination.length > 0 ) {
			ayg_init_pagination( $pagination );

			$pagination.on( 'gallery.updated', function() {
				if ( $container.find( '.ayg-active' ).length > 0 ) {
					return;
				}

				if ( $container.find( '.ayg-item-' + video_id ).length > 0 ) {
					$current_item = $container.find( '.ayg-item-' + video_id ).addClass( 'ayg-active' );
				}
			});
		}
	}

	/**
	 * Init Single Video.
	 *
	 * @since 2.0.0
	 */
	function init_single_video( $container ) {
		++ayg_public.gallery_index;

		$container.addClass( 'ayg-theme-initialized' );

		var params = $container.data( 'params' );		
		
		var player_id = 'ayg-player-' + ayg_public.gallery_index;
		$container.find( '.ayg-player-iframe' ).attr( 'id', player_id );

		// Player
		var player = ayg_init_player( player_id, {			
			custom: {
				params: params,
				image: $( '#' + player_id ).data( 'image' )
			},
			events: {
				'onStateChange': function( e ) {
					// On Playing
					if ( e.data == YT.PlayerState.PLAYING ) {
						ayg_pause_other_players( player_id );
					}

					// On Ended
					if ( e.data == YT.PlayerState.ENDED ) {
						if ( 1 == params.loop ) {
							player.play();
						}
					}				 
				}
			}
		});		
	}

	/**
	 * Init Livestream.
	 *
	 * @since 2.0.0
	 */
	function init_livestream( $container ) {
		++ayg_public.gallery_index;

		$container.addClass( 'ayg-theme-initialized' );

		var params = $container.data( 'params' );
		
		var player_id = 'ayg-player-' + ayg_public.gallery_index;
		$container.find( '.ayg-player-iframe' ).attr( 'id', player_id );	

		// Player
		var player = ayg_init_player( player_id, {			
			custom: {
				params: params,
				image: 'none'
			},
			events: {
				'onReady': function( e ) {
					var url = e.target.getVideoUrl();

					if ( url.indexOf( 'watch?v=live_stream' ) > 0 ) {
						$container.find( '.ayg-player-wrapper' ).fadeOut( 'fast', function() {
							$container.find( '.ayg-fallback-message' ).fadeIn();
						});															
					} else {
						$( '#' + player_id ).show();
					}
				},
				'onStateChange': function( e ) {
					// On Playing
					if ( e.data == YT.PlayerState.PLAYING ) {
						ayg_pause_other_players( player_id );
					}

					// On Ended
					if ( e.data == YT.PlayerState.ENDED ) {
						player.stop();
					}				 
				}
			}
		});		
	}	

	/**
	 * Init AYGPlayer.
	 *
	 * @since 2.0.0
	 */
	var ayg_init_player = function ( player_id, args ) {
		var player = null;	
		var $player_wrapper = $( '#' +  player_id ).closest( 'div' );		
		var video_id = $( '#' +  player_id ).data( 'id' );
		var params = args.custom.params;

		var init_player = function () {
			var domain = 'https://www.youtube.com';
			if ( 1 == ayg_public.privacy_enhanced_mode ) {
				domain = 'https://www.youtube-nocookie.com';
			}

			var iframe_src = domain + '/embed/' + video_id + '?enablejsapi=1';
						
			if ( params.hasOwnProperty( 'is_live' ) ) {
				iframe_src = domain + '/embed/live_stream?channel=' + video_id + '&enablejsapi=1';
			}		

			iframe_src += '&playsinline=1';
			iframe_src += '&rel=0';

			if ( ayg_public.origin ) {
				iframe_src += '&origin=' + ayg_public.origin;
			}

			if ( params.hasOwnProperty( 'autoplay' ) ) {
				iframe_src += ( '&autoplay=' + parseInt( params.autoplay ) );
			}

			if ( params.hasOwnProperty( 'muted' ) ) {
				iframe_src += ( '&mute=' + parseInt( params.muted ) );
			}
		
			if ( params.hasOwnProperty( 'controls' ) ) {
				iframe_src += ( '&controls=' + parseInt( params.controls ) );
			}
		
			if ( params.hasOwnProperty( 'modestbranding' ) ) {
				iframe_src += ( '&modestbranding=' + parseInt( params.modestbranding ) );
			}
		
			if ( params.hasOwnProperty( 'cc_load_policy' ) ) {
				iframe_src += ( '&cc_load_policy=' + parseInt( params.cc_load_policy ) );
			}
		
			if ( params.hasOwnProperty( 'iv_load_policy' ) ) {
				iframe_src += ( '&iv_load_policy=' + parseInt( params.iv_load_policy ) );
			}
		
			if ( params.hasOwnProperty( 'hl' ) ) {
				iframe_src += ( '&hl=' + params.hl );
			}
		
			if ( params.hasOwnProperty( 'cc_lang_pref' ) ) {
				iframe_src += ( '&cc_lang_pref=' + params.cc_lang_pref );
			}

			if ( $( '#' +  player_id ).prop( 'tagName' ).toLowerCase() == 'iframe' ) {
				$( '#' +  player_id ).attr( 'src', iframe_src );	
			} else {
				$( '#' +  player_id ).replaceWith( '<iframe id="' + player_id + '" class="ayg-player-iframe" width="100%" height="100%" src="' + iframe_src + '" frameborder="0" allow="accelerometer; autoplay; encrypted-media; gyroscope; picture-in-picture" allowfullscreen></iframe>' );
			}					

			player = new YT.Player( player_id, { events: args.events } );
		}	

		if ( 1 == ayg_public.cookie_consent ) {
			var html = '<div class="ayg-privacy-wrapper" style="background-image: url(' + args.custom.image + ');">';
			html += '<div class="ayg-privacy-consent-block">';
			html += '<div class="ayg-privacy-consent-message">' + ayg_public.consent_message + '</div>';
			html += '<div class="ayg-privacy-consent-button">' + ayg_public.button_label + '</div>';
			html += '</div>';
			html += '</div>';

			$player_wrapper.append( html );

			$player_wrapper.on( 'click', '.ayg-privacy-consent-button', function() {
				$( this ).html( '...' );

				var data = {
					'action': 'ayg_set_cookie',
					'security': ayg_public.ajax_nonce
				};
	
				$.post( 
					ayg_public.ajax_url, 
					data, 
					function( response ) {
						if ( response.success ) {
							ayg_public.cookie_consent = 0;

							params.autoplay = 1;
							init_player();

							$player_wrapper.find( '.ayg-privacy-wrapper' ).remove();
						}
					}
				);
			});
		} else {
			init_player();
		}	
		
		return {
			play: function() {
				if ( player && player.playVideo ) {
					player.playVideo();
				}
			},
			change: function( obj ) {
				if ( player && player.loadVideoById ) {
					player.loadVideoById( obj.id );
				} else {
					video_id = obj.id;

					if ( 1 == ayg_public.cookie_consent ) {
						$player_wrapper.find( '.ayg-privacy-wrapper' ).css( 'background-image', "url(" + obj.image + ")" );
					}
				}
			},
			stop: function() {
				if ( player && player.stopVideo ) {
					player.stopVideo();
				}
			},
			destroy: function() {
				if ( player ) {
					if ( player.stopVideo ) {
						player.stopVideo();
					}

					if ( player.destroy ) {
						player.destroy();
					}
				} else {
					$( '#' +  player_id ).remove();
				}

				if ( 1 == ayg_public.cookie_consent ) {
					$player_wrapper.find( '.ayg-privacy-wrapper' ).remove();
				}
			}
		};
	}

	window.ayg_init_player = ayg_init_player;

	/**
	 * Init Pagination.
	 *
	 * @since 2.0.0
	 */
	var ayg_init_pagination = function( $pagination ) {
		var params = $pagination.data( 'params' );

		params.action = 'ayg_load_more_videos';
		params.security = ayg_public.ajax_nonce;
		
		var total_pages = parseInt( params.total_pages );
		var paged = 1;
		var previous_page_tokens = [''];

		var $gallery = $pagination.closest( '.ayg' ).find( '.ayg-gallery' );

		// On next/more button clicked
		$pagination.on( 'click', '.ayg-pagination-next-btn', function() {
			var $this = $( this );

			$pagination.addClass( 'ayg-loading' );				

			var type = $this.data( 'type' );

			params.pageToken = params.next_page_token;
			previous_page_tokens[ paged ] = params.next_page_token;

			$.post( ayg_public.ajax_url, params, function( response ) {
				if ( response.success ) {
					paged = Math.min( paged + 1, total_pages );

					params.next_page_token = '';
					if ( paged < total_pages && response.data.next_page_token ) {
						params.next_page_token = response.data.next_page_token;
					}

					switch ( type ) {
						case 'more':
							$gallery.append( response.data.html );
							break;						
						case 'next':
							$pagination.find( '.ayg-pagination-prev-btn' ).show();
							$pagination.find( '.ayg-pagination-current-page-number' ).html( paged );		

							$gallery.html( response.data.html );
							break;
					}

					if ( '' == params.next_page_token ) {
						$this.hide();
					}

					$pagination.trigger( 'gallery.updated' );
				}

				$pagination.removeClass( 'ayg-loading' );
			});
		});

		// On previous button clicked
		$pagination.on( 'click', '.ayg-pagination-prev-btn', function() {
			var $this = $( this );

			$pagination.addClass( 'ayg-loading' );	
					
			paged = Math.max( paged - 1, 1 );

			params.pageToken = previous_page_tokens[ paged - 1 ];

			$.post( ayg_public.ajax_url, params, function( response ) {
				if ( response.success ) {
					params.next_page_token = '';
					if ( response.data.next_page_token ) {
						params.next_page_token = response.data.next_page_token;
					}

					$gallery.html( response.data.html );

					$pagination.find( '.ayg-pagination-next-btn' ).show();
					$pagination.find( '.ayg-pagination-current-page-number' ).html( paged );			

					if ( 1 == paged ) {
						$this.hide();
					}

					$pagination.trigger( 'gallery.updated' );
				}

				$pagination.removeClass( 'ayg-loading' );
			});
		});
	}

	window.ayg_init_pagination = ayg_init_pagination;

	/**
	 * Pause other players.
	 *
	 * @since 2.3.0
	 */
	var ayg_pause_other_players = function( player_id ) {
		if ( ! ayg_public.active_player_id ) {
			ayg_public.active_player_id = player_id;
		}

		if ( player_id == ayg_public.active_player_id ) {
			return false;
		}
		
		ayg_public.active_player_id = player_id;

		$( 'iframe.ayg-player-iframe:not(#' + player_id + ')' ).each(function() {
			this.contentWindow.postMessage( '{"event":"command", "func":"pauseVideo", "args":""}', '*' );
		});
	}
	
	window.ayg_pause_other_players = ayg_pause_other_players;

	/**
	 * Called when the page has loaded.
	 *
	 * @since 1.0.0
	 */
	$(function() {
		// Init Automatic YouTube Gallery
		if ( 'undefined' === typeof window['YT'] ) {
			var tag = document.createElement( 'script' );
			tag.src = "https://www.youtube.com/iframe_api";
			var first_script_tag = document.getElementsByTagName( 'script' )[0];
			first_script_tag.parentNode.insertBefore( tag, first_script_tag );		
		}
		
		if ( 'undefined' == typeof window.onYouTubeIframeAPIReady ) {
			window.onYouTubeIframeAPIReady = function() {
				ayg_init();
			};
		} else if ( 'undefined' !== typeof window.YT ) {
			ayg_init();
		}
		
		var interval = setInterval(
			function() {
				if ( 'undefined' !== typeof window.YT && window.YT.loaded )	{
					clearInterval( interval );
					ayg_init();					
				}
			}, 
			10
		);

		// Locate gallery element on single video pages
		var gallery_id = ayg_public.gallery_id;
		if ( '' != gallery_id && $( '#ayg-' + gallery_id ).length ) {
			if ( history.scrollRestoration ) {
				history.scrollRestoration = 'manual';
			} else {
				window.onbeforeunload = function () {
					window.scrollTo( 0, 0 );
				}
			}
			
			$( 'html, body' ).animate({
				scrollTop: $( '#ayg-' + gallery_id ).offset().top - ayg_public.top_offset
			}, 500);	
		}

		// Toggle more/less content in the player description
		$( document ).on( 'click', '.ayg-player-description-toggle-btn', function( event ) {
			event.preventDefault();

			var $this = $( this);
			var $description = $this.closest( '.ayg-player-description' );
			var $dots = $description.find( '.ayg-player-description-dots' );
			var $more = $description.find( '.ayg-player-description-more' );

			if ( $dots.is( ':visible' ) ) {
				$this.html( ayg_public.i18n.show_less );
				$dots.hide();
				$more.fadeIn();									
			} else {					
				$more.fadeOut(function() {
					$this.html( ayg_public.i18n.show_more );
					$dots.show();					
				});								
			}	
		});

		// Gutenberg: On block init
		if ( 'undefined' !== typeof wp && 'undefined' !== typeof wp['hooks'] ) {
			var ayg_block_interval;
			var ayg_block_interval_retry_count;

			wp.hooks.addFilter( 'ayg_block_init', 'automatic-youtube-gallery/block', function( attributes ) {
				if ( 'livestream' == attributes.type ) {
					if ( ayg_block_interval_retry_count > 0 ) {
						clearInterval( ayg_block_interval );
					}

					ayg_block_interval_retry_count = 0;

					ayg_block_interval = setInterval(
						function() {
							ayg_block_interval_retry_count++;
							var $players = $( '.ayg-theme-livestream:not(.ayg-theme-initialized)' );

							if ( $players.length > 0 || ayg_block_interval_retry_count >= 10 ) {
								clearInterval( ayg_block_interval );
								ayg_block_interval_retry_count = 0;

								$players.each(function() {
									init_livestream( $( this ) );	
								});
							}
						}, 
						1000
					);
				}

				return attributes;
			});
		}
	});

})( jQuery );